Module result

Module result 

Type aliases for the standard library I/O error and result types used throughout the crate.

Type Aliases

IoError
Alias for the standard library I/O error type.
IoErrorKind
Alias for the standard library I/O error kind enumeration.
IoResult
Alias for a Result whose error is a standard library I/O error.